@@ -31,10 +31,10 @@ try:
                 return dct
             elif isinstance(obj, np.ndarray):
                 return dict(__ndarray__=obj.tolist(), dtype=str(obj.dtype), shape=obj.shape)
+            elif isinstance(obj, (datetime, pd.Timestamp)):
+                return obj.strftime("%Y-%m-%d %H:%M:%S")
             elif isinstance(obj, date):
                 return obj.strftime("%Y-%m-%d")
-            elif isinstance(obj, datetime):
-                return obj.strftime("%Y-%m-%d %H:%M:%S")
             elif isinstance(obj, pd.Timedelta):
                 return {"__pd.Timedelta__": str(obj)}
             elif hasattr(obj, "name"):
@@ -46,7 +46,7 @@ try:
     def json_obj_hook(dct):
         if isinstance(dct, dict) and "__ndarray__" in dct:
             return np.array(dct["__ndarray__"], dct["dtype"]).reshape(dct["shape"])
-        if isinstance(dct, dict) and "__pd.Timedelta__" in dct and len(dict) == 1:
+        if isinstance(dct, dict) and "__pd.Timedelta__" in dct and len(dct) == 1:
             return pd.Timedelta(dct["__pd.Timedelta__"])
         elif isinstance(dct, dict) and "columns" in dct and "data" in dct and "datetimeindex" in dct:
             possible_keys = ["data", "index", "dtypes", "columns", "datetimeindex"]
